#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-2yClP7UdHyHLwKA7WlCcG4
key:                  interpolatedstring-perl6-1.0.2-2yClP7UdHyHLwKA7WlCcG4
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  8d23ec0315a61431c94c8c4e831bb042
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-2yClP7UdHyHLwKA7WlCcG4
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.15-2oXG0ApGRlh10pa79nVDBD
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

